@@ -4,6 +4,7 @@ import os
 import os.path
 from cerberus import Validator
 from enum import Enum
+from jiraworklog.exceptions import JiraworklogError
 import yaml
 import yaml.parser
 
@@ -80,7 +81,7 @@ class ResolveConfPath:
         return msg
 
 
-class ConfigOSReadError(RuntimeError):
+class ConfigOSReadError(JiraworklogError):
 
     def __init__(
         self,
@@ -98,7 +99,7 @@ class ConfigOSReadError(RuntimeError):
         return msg
 
 
-class ConfigYAMLError(RuntimeError):
+class ConfigYAMLError(JiraworklogError):
 
     def __init__(
         self,
@@ -115,7 +116,7 @@ class ConfigYAMLError(RuntimeError):
         return msg
 
 
-class ConfigParseError(RuntimeError):
+class ConfigParseError(JiraworklogError):
 
     validator: Optional[Validator]
 
