@@ -3,9 +3,10 @@
 from jira import JIRA, JIRAError
 from jiraworklog.auth_jira import fmt_jira_error
 from jiraworklog.configuration import Configuration
+from jiraworklog.exceptions import JiraworklogError
 from jiraworklog.worklogs import WorklogJira
 
-class ReadJiraWorkloadError(Exception):
+class ReadJiraWorkloadError(JiraworklogError):
 
     def __init__(self, wkl_nm: str, jira_error: JIRAError) -> None:
         msg = (
